==> esp8266-0.3.0.crate: esp8266-0.3.0/src/efuse/efuse_data1.rs <==
#[doc = "Register `EFUSE_DATA1` reader"]
pub struct R(crate::R<EFUSE_DATA1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<EFUSE_DATA1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<EFUSE_DATA1_SPEC>> for R {
    fn from(reader: crate::R<EFUSE_DATA1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `EFUSE_DATA1` writer"]
pub struct W(crate::W<EFUSE_DATA1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<EFUSE_DATA1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<EFUSE_DATA1_SPEC>> for W {
    fn from(writer: crate::W<EFUSE_DATA1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `Register` reader - "]
pub struct REGISTER_R(crate::FieldReader<u32, u32>);
impl REGISTER_R {
    pub(crate) fn new(bits: u32) -> Self {
        REGISTER_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for REGISTER_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `Register` writer - "]
pub struct REGISTER_W<'a> {
    w: &'a mut W,
}
impl<'a> REGISTER_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | ((value as u32) & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn register(&self) -> REGISTER_R {
        REGISTER_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn register(&mut self) -> REGISTER_W {
        REGISTER_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "EFUSE_DATA1\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [efuse_data1](index.html) module"]
pub struct EFUSE_DATA1_SPEC;
impl crate::RegisterSpec for EFUSE_DATA1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [efuse_data1::R](R) reader structure"]
impl crate::Readable for EFUSE_DATA1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [efuse_data1::W](W) writer structure"]
impl crate::Writable for EFUSE_DATA1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets EFUSE_DATA1 to value 0"]
impl crate::Resettable for EFUSE_DATA1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/efuse/efuse_data1.rs <==
#[doc = "Register `EFUSE_DATA1` reader"]
pub struct R(crate::R<EFUSE_DATA1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<EFUSE_DATA1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<EFUSE_DATA1_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<EFUSE_DATA1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `EFUSE_DATA1` writer"]
pub struct W(crate::W<EFUSE_DATA1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<EFUSE_DATA1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<EFUSE_DATA1_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<EFUSE_DATA1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `Register` reader - "]
pub struct REGISTER_R(crate::FieldReader<u32, u32>);
impl REGISTER_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        REGISTER_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for REGISTER_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `Register` writer - "]
pub struct REGISTER_W<'a> {
    w: &'a mut W,
}
impl<'a> REGISTER_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value as u32;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn register(&self) -> REGISTER_R {
        REGISTER_R::new(self.bits as u32)
    }
}
impl W {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn register(&mut self) -> REGISTER_W {
        REGISTER_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "EFUSE_DATA1\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [efuse_data1](index.html) module"]
pub struct EFUSE_DATA1_SPEC;
impl crate::RegisterSpec for EFUSE_DATA1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [efuse_data1::R](R) reader structure"]
impl crate::Readable for EFUSE_DATA1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [efuse_data1::W](W) writer structure"]
impl crate::Writable for EFUSE_DATA1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets EFUSE_DATA1 to value 0"]
impl crate::Resettable for EFUSE_DATA1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
